Install Kedro — Kedro 0.17.6 documentation

# Install Kedro

To install Kedro from the Python Package Index (PyPI) simply run:

    pip install kedro

Note

It is also possible to install Kedro using `conda`, as follows, but we recommend using `pip` at this point to eliminate any potential dependency issues, as follows:

    conda install -c conda-forge kedro

Both `pip` and `conda` install the core Kedro module, which includes the CLI tool, project template, pipeline abstraction, framework, and support for configuration.

## Verify a successful installation

To check that Kedro is installed:

    kedro info

You should see an ASCII art graphic and the Kedro version number. For example:

If you do not see the graphic displayed, or have any issues with your installation, see the frequently asked questions, check out GitHub Discussions or talk to the community on the Discord Server.

## Install a development version

You can try out a development version of Kedro direct from the Kedro Github repository by following these steps.